@@ -32,13 +32,31 @@
 #include "authentication.h"
 #include <libedataserver/e-url.h>
 
+static gboolean
+get_remember_password (ESource *source)
+{
+	const gchar *value;
+
+	value = e_source_get_property (source, "remember_password");
+	if (value && !g_ascii_strcasecmp (value, "true"))
+		return TRUE;
+
+	return FALSE;
+}
+
+static void
+set_remember_password (ESource *source, gboolean value)
+{
+	e_source_set_property (source, "remember_password",
+			       value ? "true" : "false");
+}
+
 static gchar *
 auth_func_cb (ECal *ecal,
               const gchar *prompt,
               const gchar *key,
               gpointer user_data)
 {
-	gboolean remember;
 	gchar *password, *auth_domain;
 	ESource *source;
 	const gchar *component_name;
@@ -48,7 +66,11 @@ auth_func_cb (ECal *ecal,
 	component_name = auth_domain ? auth_domain : "Calendar";
 	password = e_passwords_get_password (component_name, key);
 
-	if (!password)
+	if (!password) {
+		gboolean remember;
+
+		remember = get_remember_password (source);
+
 		password = e_passwords_ask_password (
 			_("Enter password"),
 			component_name, key, prompt,
@@ -57,6 +79,10 @@ auth_func_cb (ECal *ecal,
 			E_PASSWORDS_ONLINE,
 			&remember, NULL);
 
+		if (password)
+			set_remember_password (source, remember);
+	}
+
 	g_free (auth_domain);
 
 	return password;
@@ -131,7 +157,6 @@ typedef struct {
 	icaltimezone *default_zone;
 
 	/* Authentication Details */
-	gchar *auth_uri;
 	gchar *auth_component;
 } LoadContext;
 
@@ -147,7 +172,6 @@ load_cal_source_context_free (LoadContext *context)
 	if (context->cancellable != NULL)
 		g_object_unref (context->cancellable);
 
-	g_free (context->auth_uri);
 	g_free (context->auth_component);
 
 	g_slice_free (LoadContext, context);
@@ -177,28 +201,47 @@ static gchar *
 load_cal_source_authenticate (ECal *cal,
                               const gchar *prompt,
                               const gchar *uri,
-                              LoadContext *context)
+                              gpointer not_used)
 {
+	const gchar *auth_component;
 	const gchar *title;
-	gboolean remember;  /* not used */
+	GtkWindow *parent;
 	gchar *password;
 
+	/* XXX Dig up authentication info embedded in the ECal instance.
+	 * (See load_cal_source_thread() for an explanation of why.) */
+	auth_component = g_object_get_data (G_OBJECT (cal), "auth-component");
+	g_return_val_if_fail (auth_component != NULL, NULL);
+
+	parent = g_object_get_data (G_OBJECT (cal), "parent-window");
+
 	/* Remember the URI so we don't have to reconstruct it if
 	 * authentication fails and we have to forget the password. */
-	g_free (context->auth_uri);
-	context->auth_uri = g_strdup (uri);
+	g_object_set_data_full (
+		G_OBJECT (cal),
+		"auth-uri", g_strdup (uri),
+		(GDestroyNotify) g_free);
 
 	/* XXX Dialog windows should not have titles. */
 	title = "";
 
-	password = e_passwords_get_password (context->auth_component, uri);
+	password = e_passwords_get_password (auth_component, uri);
+
+	if (password == NULL) {
+		gboolean remember;
+		ESource *source = e_cal_get_source (cal);
+
+		remember = get_remember_password (source);
 
-	if (password == NULL)
 		password = e_passwords_ask_password (
-			title, context->auth_component, uri,
+			title, auth_component, uri,
 			prompt, E_PASSWORDS_REMEMBER_FOREVER |
 			E_PASSWORDS_SECRET | E_PASSWORDS_ONLINE,
-			&remember, context->parent);
+			&remember, parent);
+
+		if (password)
+			set_remember_password (source, remember);
+	}
 
 	return password;
 }
@@ -233,20 +276,28 @@ load_cal_source_thread (GSimpleAsyncResult *simple,
 		return;
 	}
 
-	/* XXX Why doesn't EBook have something like this? */
+	/* XXX e_cal_set_auth_func() does not take a GDestroyNotify callback
+	 *     for the 'user_data' argument, which makes the argument rather
+	 *     useless.  So instead, we'll embed the information needed by
+	 *     the authentication callback directly into the ECal instance
+	 *     using g_object_set_data_full(). */
+	g_object_set_data_full (
+		G_OBJECT (cal), "auth-component",
+		g_strdup (context->auth_component),
+		(GDestroyNotify) g_free);
+	if (context->parent != NULL)
+		g_object_set_data_full (
+			G_OBJECT (cal), "parent-window",
+			g_object_ref (context->parent),
+			(GDestroyNotify) g_object_unref);
+
 	e_cal_set_auth_func (
-		cal, (ECalAuthFunc)
-		load_cal_source_authenticate, context);
+		cal, (ECalAuthFunc) load_cal_source_authenticate, NULL);
 
 try_again:
 	if (!e_cal_open (cal, FALSE, &error))
 		goto fail;
 
-	/* We should be authenticated now if we're going to be,
-	 * so remove the authentication callback so it doesn't
-	 * get triggered after we free the load context. */
-	e_cal_set_auth_func (cal, NULL, NULL);
-
 	if (g_cancellable_set_error_if_cancelled (cancellable, &error)) {
 		g_simple_async_result_set_from_error (simple, error);
 		g_object_unref (cal);
@@ -265,8 +316,13 @@ fail:
 	if (g_error_matches (
 		error, E_CALENDAR_ERROR,
 		E_CALENDAR_STATUS_AUTHENTICATION_FAILED)) {
+		const gchar *auth_uri;
+
+		/* Retrieve the URI set by the authentication function. */
+		auth_uri = g_object_get_data (G_OBJECT (cal), "auth-uri");
+
 		e_passwords_forget_password (
-			context->auth_component, context->auth_uri);
+			context->auth_component, auth_uri);
 		g_clear_error (&error);
 		goto try_again;
 
