@@ -33,7 +33,6 @@
 #include <glib/gi18n.h>
 #include <misc/e-dateedit.h>
 #include <misc/e-url-entry.h>
-#include "../calendar-config.h"
 #include "../e-timezone-entry.h"
 #include "comp-editor-util.h"
 #include "task-details-page.h"
@@ -42,10 +41,6 @@
 #include "e-util/e-dialog-widgets.h"
 #include "e-util/e-util-private.h"
 
-#define TASK_DETAILS_PAGE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), TYPE_TASK_DETAILS_PAGE, TaskDetailsPagePrivate))
-
 struct _TaskDetailsPagePrivate {
 	GtkBuilder *builder;
 
@@ -178,7 +173,7 @@ task_details_page_dispose (GObject *object)
 {
 	TaskDetailsPagePrivate *priv;
 
-	priv = TASK_DETAILS_PAGE_GET_PRIVATE (object);
+	priv = TASK_DETAILS_PAGE (object)->priv;
 
 	if (priv->main != NULL) {
 		g_object_unref (priv->main);
@@ -227,12 +222,15 @@ task_details_page_fill_widgets (CompEditorPage *page,
 	gint *priority_value, *percent = NULL;
 	TaskEditorPriority priority;
 	icalproperty_status status;
+	CompEditor *editor;
 	const gchar *url;
 	struct icaltimetype *completed = NULL;
 
 	tdpage = TASK_DETAILS_PAGE (page);
 	priv = tdpage->priv;
 
+	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (tdpage));
+
 	/* Clean the screen */
 	clear_widgets (tdpage);
 
@@ -274,7 +272,7 @@ task_details_page_fill_widgets (CompEditorPage *page,
 		/* Completed is in UTC, but that would confuse the user, so
 		   we convert it to local time. */
 		utc_zone = icaltimezone_get_utc_timezone ();
-		zone = calendar_config_get_icaltimezone ();
+		zone = comp_editor_get_timezone (editor);
 
 		icaltimezone_convert_time (completed, utc_zone, zone);
 
@@ -316,14 +314,18 @@ task_details_page_fill_component (CompEditorPage *page,
 	struct icaltimetype icalcomplete, icaltoday;
 	icalproperty_status status;
 	TaskEditorPriority priority;
+	CompEditor *editor;
 	gint priority_value, percent;
 	gchar *url;
 	gboolean date_set;
-	icaltimezone *zone = calendar_config_get_icaltimezone ();
+	icaltimezone *zone;
 
 	tdpage = TASK_DETAILS_PAGE (page);
 	priv = tdpage->priv;
 
+	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (tdpage));
+	zone = comp_editor_get_timezone (editor);
+
 	/* Percent Complete. */
 	percent = gtk_spin_button_get_value_as_int (
 		GTK_SPIN_BUTTON (priv->percent_complete));
@@ -365,7 +367,7 @@ task_details_page_fill_component (CompEditorPage *page,
 		/* COMPLETED today or before */
 		icaltoday = icaltime_current_time_with_zone (zone);
 		icaltimezone_convert_time (&icaltoday, zone,
-				icaltimezone_get_utc_timezone());
+				icaltimezone_get_utc_timezone ());
 
 		if (icaltime_compare_date_only (icalcomplete, icaltoday) > 0) {
 			comp_editor_page_display_validation_error (
@@ -434,7 +436,8 @@ task_details_page_class_init (TaskDetailsPageClass *class)
 static void
 task_details_page_init (TaskDetailsPage *tdpage)
 {
-	tdpage->priv = TASK_DETAILS_PAGE_GET_PRIVATE (tdpage);
+	tdpage->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		tdpage, TYPE_TASK_DETAILS_PAGE, TaskDetailsPagePrivate);
 }
 
 /* Gets the widgets from the XML file and returns if they are all available. */
@@ -498,7 +501,7 @@ complete_date_changed (TaskDetailsPage *tdpage, time_t ctime, gboolean complete)
 {
 	CompEditorPageDates dates = {NULL, NULL, NULL, NULL};
 	icaltimezone *zone;
-	struct icaltimetype completed_tt = icaltime_null_time();
+	struct icaltimetype completed_tt = icaltime_null_time ();
 
 	/* Get the current time in UTC. */
 	zone = icaltimezone_get_utc_timezone ();
@@ -661,14 +664,19 @@ init_widgets (TaskDetailsPage *tdpage)
 {
 	TaskDetailsPagePrivate *priv;
 	GtkAdjustment *adjustment;
+	CompEditor *editor;
 
 	priv = tdpage->priv;
 
+	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (tdpage));
+
 	/* Make sure the EDateEdit widgets use our timezones to get the
 	   current time. */
-	e_date_edit_set_get_time_callback (E_DATE_EDIT (priv->completed_date),
-					   (EDateEditGetTimeCallback) comp_editor_get_current_time,
-					   tdpage, NULL);
+	e_date_edit_set_get_time_callback (
+		E_DATE_EDIT (priv->completed_date),
+		(EDateEditGetTimeCallback) comp_editor_get_current_time,
+		g_object_ref (editor),
+		(GDestroyNotify) g_object_unref);
 
 	/* These are created by hand, so hook the mnemonics manually */
 	gtk_label_set_mnemonic_widget (
