@@ -102,8 +102,8 @@ e_cal_model_calendar_finalize (GObject *object)
 		model->priv = NULL;
 	}
 
-	if (G_OBJECT_CLASS (e_cal_model_calendar_parent_class)->finalize)
-		G_OBJECT_CLASS (e_cal_model_calendar_parent_class)->finalize (object);
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (e_cal_model_calendar_parent_class)->finalize (object);
 }
 
 /* ETableModel methods */
